@@ -20,14 +20,15 @@ from pandas import DataFrame as df
 from pytz import timezone
 from pytz.tzinfo import DstTzInfo
 
-from common import config, market_data, trading_data
-from common.database import create_db_connection
-from common.tlog import tlog
-from fincalcs.data_conditions import QUOTE_SKIP_CONDITIONS, TRADE_CONDITIONS
-from models.new_trades import NewTrade
-from models.trending_tickers import TrendingTickers
-from strategies.base import Strategy
-from strategies.momentum_long import MomentumLong
+from liualgotrader.common import config, market_data, trading_data
+from liualgotrader.common.database import create_db_connection
+from liualgotrader.common.tlog import tlog
+from liualgotrader.fincalcs.data_conditions import (QUOTE_SKIP_CONDITIONS,
+                                                    TRADE_CONDITIONS)
+from liualgotrader.models.new_trades import NewTrade
+from liualgotrader.models.trending_tickers import TrendingTickers
+from liualgotrader.strategies.base import Strategy
+from liualgotrader.strategies.momentum_long import MomentumLong
 
 
 async def end_time(reason: str):
@@ -631,14 +632,16 @@ async def consumer_async_main(
 
                 if not issubclass(custom_strategy, Strategy):
                     tlog(
-                        f"custom scanner must inherit from class {Strategy.__name__}"
+                        f"custom strartegy must inherit from class {Strategy.__name__}"
                     )
                     exit(0)
-
+                strategy_details.pop("filename", None)
                 strategy_types += [(custom_strategy, strategy_details)]
 
             except Exception as e:
-                tlog(f"Error {e}")
+                tlog(
+                    f"[Error]exception of type {type(e).__name__} with args {e.args}"
+                )
                 exit(0)
 
     for strategy_tuple in strategy_types:
@@ -734,9 +737,14 @@ def consumer_main(
 ) -> None:
     tlog(f"*** consumer_main() starting w pid {os.getpid()} ***")
 
-    config.build_label = pygit2.Repository("./").describe(
-        describe_strategy=pygit2.GIT_DESCRIBE_TAGS
-    )
+    try:
+        config.build_label = pygit2.Repository("../").describe(
+            describe_strategy=pygit2.GIT_DESCRIBE_TAGS
+        )
+    except pygit2.GitError:
+        import liualgotrader
+
+        config.build_label = liualgotrader.__version__ if hasattr(liualgotrader, "__version__") else ""  # type: ignore
 
     config.bypass_market_schedule = conf.get("bypass_market_schedule", False)
 
